==> haskell-sandi-0.5-98-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-GVZLTIeZ2P7tD4j4yrszG
key:                  sandi-0.5-GVZLTIeZ2P7tD4j4yrszG
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  f5f0a95924a54981b663acf4a7655581
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-8.8.3/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/sandi-0.5
hs-libraries:         HSsandi-0.5-GVZLTIeZ2P7tD4j4yrszG
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    conduit-1.3.2-9pHLGmt2xd1FBZnMZrqws2
    exceptions-0.10.4-IWqfFitgKOeJT066q48Qo6

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sandi-0.5-99-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-sandi.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 sandi
version:              0.5
visibility:           public
id:                   sandi-0.5-FYNG2OTJjnVLWB7TMTNI3o
key:                  sandi-0.5-FYNG2OTJjnVLWB7TMTNI3o
license:              BSD-3-Clause
maintainer:           Magnus Therning <magnus@therning.org>
synopsis:             Data encoding library
description:          Reasonably fast data encoding library.
category:             Codec, Conduit
abi:                  5822651f1c3f987446768f87994083fe
exposed:              True
exposed-modules:
    Codec.Binary.Base16 Codec.Binary.Base32 Codec.Binary.Base32Hex
    Codec.Binary.Base64 Codec.Binary.Base64Url Codec.Binary.Base85
    Codec.Binary.QuotedPrintable Codec.Binary.Uu Codec.Binary.Xx
    Codec.Binary.Yenc Data.Conduit.Codec.Base16
    Data.Conduit.Codec.Base32 Data.Conduit.Codec.Base32Hex
    Data.Conduit.Codec.Base64 Data.Conduit.Codec.Base64Url
    Data.Conduit.Codec.Base85 Data.Conduit.Codec.QuotedPrintable
    Data.Conduit.Codec.Uu Data.Conduit.Codec.Xx Data.Conduit.Codec.Yenc

hidden-modules:       Paths_sandi Data.Conduit.Codec.Util
import-dirs:          /usr/lib/ghc-8.8.3/site-local/sandi-0.5
library-dirs:         /usr/lib/ghc-8.8.3/site-local/sandi-0.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/sandi-0.5
hs-libraries:         HSsandi-0.5-FYNG2OTJjnVLWB7TMTNI3o
depends:
    base-4.13.0.0 bytestring-0.10.10.0
    conduit-1.3.2-9pHLGmt2xd1FBZnMZrqws2
    exceptions-0.10.4-IWqfFitgKOeJT066q48Qo6

haddock-interfaces:   /usr/share/doc/haskell-sandi/html/sandi.haddock
haddock-html:         /usr/share/doc/haskell-sandi/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
